## 0.0.8.0

- Fixed zipfile.Path.open encoding

## 0.0.7.0

- Introduced \_\_version\_\_

## 0.0.6.0

- Support inflate64/pyzstd modules (they are fallbacks, the feature does not change)

## 0.0.5.3

- Fixed pypi desc display

## 0.0.5.2

- Fixed Python 3.4/3.5 compatibility

## 0.0.5.1

- Added bzip2 compress level 11-19

## 0.0.5.0

- Added deflate64 compression support

## 0.0.4.2

- Fixed pyppmd 0.17.0 compatibility

## 0.0.4.1

- Fixed dclimplode version header

## 0.0.4

- Added dclimplode support

## 0.0.3.1

- Fixed extracting to file was not working on Python2

## 0.0.3

- add slz support
- changed compresslevel scheme

## 0.0.2.1

- fixed a typo in ppmd handler

## 0.0.2

- simplified xz handler

## 0.0.1.3

- finalized ppmd handler

## 0.0.1.2

- related to ppmd

## 0.0.1.1

- integrated isal

## 0.0.1

- add deflate64 decompression support
- add ppmd handler
- add compression level support for LZMA

## 0.0.0.5

- add threads= to zstandard

## 0.0.0.4

- fixed open('r') on Python2

## 0.0.0.3

- fixed Python3 compatibility

## 0.0.0.2

- fixed Python2

## 0.0.0.1

- initial version
- add xz handler
